@@ -19,6 +19,7 @@ class ProjectsMixin(object):
             "integration_dashboards",
             "first_visit",
             "newsletter_config",
+            "photo",
         ]
     )
 
@@ -72,7 +73,13 @@ class ProjectsMixin(object):
         return self._process_response(res)
 
     def new_project(
-        self, title, owner_id=None, locator=None, default_sort=None, project_id=None
+        self,
+        title,
+        owner_id=None,
+        locator=None,
+        default_sort=None,
+        project_id=None,
+        photo=None,
     ):
         """Create a new project.
 
@@ -92,14 +99,19 @@ class ProjectsMixin(object):
             project with the provided id. The length of the parameter must
             be 22 characters. Useful when exporting and importing projects
             across multiple Squirro servers.
+        :param photo: Address to the photo of the project
         :returns: A dictionary which contains the project identifier.
 
         Example::
 
             >>> locator = {'index_server': 'http://10.0.0.1:9200'}
             >>> default_sort = [{'relevance': {'order': 'asc'}}]
-            >>> client.new_project('My Project', locator=locator,
-            ...                    default_sort=default_sort)
+            >>> client.new_project(
+                    'My Project',
+                    locator=locator,
+                    default_sort=default_sort,
+                    photo='https://twitter.com/Cristiano/photo',
+                )
             {u'id': u'gd9eIipOQ-KobU0SwJ8VcQ'}
         """
 
@@ -119,6 +131,8 @@ class ProjectsMixin(object):
             data["locator"] = json.dumps(locator)
         if default_sort is not None:
             data["default_sort"] = json.dumps(default_sort)
+        if photo is not None:
+            data["photo"] = photo
 
         res = self._perform_request("post", url, data=data)
         return self._process_response(res, [201])
@@ -150,6 +164,7 @@ class ProjectsMixin(object):
         import_project_configuration=True,
         import_project_configuration_values=True,
         import_project_translations=True,
+        import_project_picture=True,
         import_smartfilters=True,
         import_sources=True,
         import_sources_dataloader_plugins=True,
@@ -224,6 +239,8 @@ class ProjectsMixin(object):
             the import_project_configuration_values, defaults to `True`.
         :param import_project_translations: Boolean. Whether to include the
             project translations, defaults to `True`.
+        :param import_project_picture: Boolean. Whether to include the
+            project picture, defaults to `True`.
         :param import_smartfilters: Boolean. Whether to include the
             smartfilters, defaults to `True`.
         :param import_sources: Boolean. Whether to include the sources,
@@ -286,6 +303,7 @@ class ProjectsMixin(object):
             "import_project_configuration": import_project_configuration,
             "import_project_configuration_values": import_project_configuration_values,
             "import_project_translations": import_project_translations,
+            "import_project_picture": import_project_picture,
             "import_smartfilters": import_smartfilters,
             "import_sources": import_sources,
             "import_sources_dataloader_plugins": import_sources_dataloader_plugins,
@@ -432,6 +450,7 @@ class ProjectsMixin(object):
         export_project_configuration=True,
         export_project_configuration_values=True,
         export_project_translations=True,
+        export_project_picture=True,
         export_smartfilters=True,
         export_sources=True,
         export_sources_dataloader_plugins=True,
@@ -515,6 +534,8 @@ class ProjectsMixin(object):
             the export_project_configuration_values, defaults to `True`.
         :param export_project_translations: Boolean. Whether to include the
             project translations, defaults to `True`.
+        :param export_project_picture: Boolean. Whether to include the
+            project picture, defaults to `True`.
         :param export_smartfilters: Boolean. Whether to include the
             smartfilters, defaults to `True`.
         :param export_sources: Boolean. Whether to include the sources,
@@ -570,6 +591,7 @@ class ProjectsMixin(object):
             "export_project_configuration": export_project_configuration,
             "export_project_configuration_values": export_project_configuration_values,
             "export_project_translations": export_project_translations,
+            "export_project_picture": export_project_picture,
             "export_smartfilters": export_smartfilters,
             "export_sources": export_sources,
             "export_sources_dataloader_plugins": export_sources_dataloader_plugins,
@@ -667,6 +689,7 @@ class ProjectsMixin(object):
         import_project_configuration=True,
         import_project_configuration_values=True,
         import_project_translations=True,
+        import_project_picture=True,
         import_smartfilters=True,
         import_sources=True,
         import_sources_dataloader_plugins=True,
@@ -747,6 +770,8 @@ class ProjectsMixin(object):
             the import_project_configuration_values, defaults to `True`.
         :param import_project_translations: Boolean. Whether to include the
             project translations, defaults to `True`.
+        :param import_project_picture: Boolean. Whether to include the
+            project picture, defaults to `True`.
         :param import_smartfilters: Boolean. Whether to include the
             smartfilters, defaults to `True`.
         :param import_sources: Boolean. Whether to include the sources,
@@ -798,6 +823,7 @@ class ProjectsMixin(object):
             "import_project_configuration": import_project_configuration,
             "import_project_configuration_values": import_project_configuration_values,
             "import_project_translations": import_project_translations,
+            "import_project_picture": import_project_picture,
             "import_smartfilters": import_smartfilters,
             "import_sources": import_sources,
             "import_sources_dataloader_plugins": import_sources_dataloader_plugins,
