@@ -1,5 +1,7 @@
 import json
 
+from squirro_client.util import deprecation
+
 
 class SourcesMixin(object):
     def get_sources(
@@ -318,8 +320,9 @@ class SourcesMixin(object):
             Source.
         :param pipeline_workflow_id: Optional pipeline workflow id to change
             the source to.
-        :param enable_scheduling: Optional boolean. Indicate whether or not to enable the
-            scheduling of this source.
+        :param enable_scheduling: DEPRECATED; Will be removed in a future release.
+            Optional boolean. Indicate whether or not to enable the scheduling of this
+            source.
         :param validate_schema: Optional boolean. Indicate whether or not to validate the
             provided configuration of the source.
         :param notify_scheduler: Optional boolean. Indicate whether or not to notify
@@ -379,6 +382,10 @@ class SourcesMixin(object):
         if pipeline_workflow_id is not None:
             data["pipeline_workflow_id"] = pipeline_workflow_id
         if enable_scheduling is not None:
+            deprecation(
+                "enable_scheduling is deprecated and it will be removed in a "
+                "future release"
+            )
             data["enable_scheduling"] = enable_scheduling
         if validate_schema is not None:
             data["validate_schema"] = validate_schema
